@@ -21,68 +21,72 @@
 #'
 #' @examples
 #' # binary classification
+#' if (requireNamespace("lightgbm", quietly = TRUE) &&
+#' requireNamespace("mlbench", quietly = TRUE) &&
+#' requireNamespace("measures", quietly = TRUE)) {
 #'
-#' library(mlbench)
-#' data("PimaIndiansDiabetes2")
-#' dataset <- PimaIndiansDiabetes2 |>
-#'   data.table::as.data.table() |>
-#'   na.omit()
+#'   library(mlbench)
+#'   data("PimaIndiansDiabetes2")
+#'   dataset <- PimaIndiansDiabetes2 |>
+#'     data.table::as.data.table() |>
+#'     na.omit()
 #'
-#' seed <- 123
-#' feature_cols <- colnames(dataset)[1:8]
+#'   seed <- 123
+#'   feature_cols <- colnames(dataset)[1:8]
 #'
-#' param_list_lightgbm <- expand.grid(
-#'   bagging_fraction = seq(0.6, 1, .2),
-#'   feature_fraction = seq(0.6, 1, .2),
-#'   min_data_in_leaf = seq(10, 50, 10),
-#'   learning_rate = seq(0.1, 0.2, 0.1),
-#'   num_leaves = seq(10, 50, 10),
-#'   max_depth = -1L
-#' )
+#'   param_list_lightgbm <- expand.grid(
+#'     bagging_fraction = seq(0.6, 1, .2),
+#'     feature_fraction = seq(0.6, 1, .2),
+#'     min_data_in_leaf = seq(10, 50, 10),
+#'     learning_rate = seq(0.1, 0.2, 0.1),
+#'     num_leaves = seq(10, 50, 10),
+#'     max_depth = -1L
+#'   )
 #'
-#' train_x <- model.matrix(
-#'   ~ -1 + .,
-#'   dataset[, .SD, .SDcols = feature_cols]
-#' )
-#' train_y <- as.integer(dataset[, get("diabetes")]) - 1L
+#'   train_x <- model.matrix(
+#'     ~ -1 + .,
+#'     dataset[, .SD, .SDcols = feature_cols]
+#'   )
+#'   train_y <- as.integer(dataset[, get("diabetes")]) - 1L
 #'
-#' fold_list <- splitTools::create_folds(
-#'   y = train_y,
-#'   k = 3,
-#'   type = "stratified",
-#'   seed = seed
-#' )
-#' lightgbm_cv <- mlexperiments::MLCrossValidation$new(
-#'   learner = mllrnrs::LearnerLightgbm$new(
-#'     metric_optimization_higher_better = FALSE
-#'   ),
-#'   fold_list = fold_list,
-#'   ncores = 2,
-#'   seed = 123
-#' )
-#' lightgbm_cv$learner_args <- c(
-#'   as.list(
-#'     data.table::data.table(
-#'       param_list_lightgbm[37, ],
-#'       stringsAsFactors = FALSE
+#'   fold_list <- splitTools::create_folds(
+#'     y = train_y,
+#'     k = 3,
+#'     type = "stratified",
+#'     seed = seed
+#'   )
+#'   lightgbm_cv <- mlexperiments::MLCrossValidation$new(
+#'     learner = mllrnrs::LearnerLightgbm$new(
+#'       metric_optimization_higher_better = FALSE
 #'     ),
-#'   ),
-#'   list(
-#'     objective = "binary",
-#'     metric = "binary_logloss"
-#'   ),
-#'   nrounds = 45L
-#' )
-#' lightgbm_cv$performance_metric_args <- list(positive = "1", negative = "0")
-#' lightgbm_cv$performance_metric <- mlexperiments::metric("AUC")
+#'     fold_list = fold_list,
+#'     ncores = 2,
+#'     seed = 123
+#'   )
+#'   lightgbm_cv$learner_args <- c(
+#'     as.list(
+#'       data.table::data.table(
+#'         param_list_lightgbm[37, ],
+#'         stringsAsFactors = FALSE
+#'       ),
+#'     ),
+#'     list(
+#'       objective = "binary",
+#'       metric = "binary_logloss"
+#'     ),
+#'     nrounds = 45L
+#'   )
+#'   lightgbm_cv$performance_metric_args <- list(positive = "1", negative = "0")
+#'   lightgbm_cv$performance_metric <- mlexperiments::metric("AUC")
 #'
-#' # set data
-#' lightgbm_cv$set_data(
-#'   x = train_x,
-#'   y = train_y
-#' )
+#'   # set data
+#'   lightgbm_cv$set_data(
+#'     x = train_x,
+#'     y = train_y
+#'   )
 #'
-#' lightgbm_cv$execute()
+#'   lightgbm_cv$execute()
+#' }
 #'
 #' @export
 #'
@@ -101,7 +105,9 @@ LearnerLightgbm <- R6::R6Class(
     #' @return A new `LearnerLightgbm` R6 object.
     #'
     #' @examples
-    #' LearnerLightgbm$new(metric_optimization_higher_better = FALSE)
+    #' if (requireNamespace("lightgbm", quietly = TRUE)) {
+    #'   LearnerLightgbm$new(metric_optimization_higher_better = FALSE)
+    #' }
     #'
     initialize = function(metric_optimization_higher_better) {
       # nolint
@@ -139,17 +145,14 @@ lightgbm_ce <- function() {
 }
 
 lightgbm_bsF <- function(...) {
-  # nolint
-
   params <- list(...)
-
   set.seed(seed) #, kind = "L'Ecuyer-CMRG")
   bayes_opt_lightgbm <- lightgbm_optimization(
     x = x,
     y = y,
     params = params,
     fold_list = method_helper$fold_list,
-    ncores = 1L, # important, as bayesian search is already parallelized
+    ncores = ncores,
     seed = seed
   )
 
