@@ -5,7 +5,7 @@ NULL
 
 #% https://community.rstudio.com/t/how-to-solve-no-visible-binding-for-global-
 #% variable-note/28887
-utils::globalVariables(c("seed", "method_helper", "x", "y"))
+utils::globalVariables(c("seed", "method_helper", "x", "y", "ncores"))
 
 mlexperiments_default_options <- list(
   mlexperiments.optim.xgb.nrounds = 5000L,
@@ -22,7 +22,9 @@ mlexperiments_default_options <- list(
 .onLoad <- function(libname, pkgname) {
   op <- options()
   toset <- !(names(mlexperiments_default_options) %in% names(op))
-  if (any(toset)) options(mlexperiments_default_options[toset])
+  if (any(toset)) {
+    options(mlexperiments_default_options[toset])
+  }
   invisible()
 }
 
